@@ -10,6 +10,7 @@ file_endings = {
     ".sass": "sass",
     ".css": "css",
     ".js": "js",
+    ".json": "js",
     ".html": "html",
     ".htm": "html",
     ".tpl": "html",
@@ -66,14 +67,14 @@ def watch_files(file_path, settings: dict):
 
 def determine_file_extension(file_path: str):
     if not file_path:
-        return None
+        return None, ""
     index = file_path.rfind(".")
     if index < 0:
-        return None
+        return None, ""
     file_ending = file_path[index:]
     if not file_ending:
-        return None
-    return file_endings.get(file_ending, None)
+        return None, ""
+    return file_endings.get(file_ending, None), file_ending
 
 
 def read_file(fname, strip=True):
